@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2011-2020 The Octave Project Developers
+// Copyright (C) 2011-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -48,10 +48,9 @@
 #include "gui-preferences-fb.h"
 #include "gui-preferences-global.h"
 #include "octave-qobject.h"
+#include "octave-qtutils.h"
 #include "qt-interpreter-events.h"
 
-#include "interpreter.h"
-#include "load-save.h"
 #include "oct-env.h"
 
 namespace octave
@@ -105,18 +104,6 @@ namespace octave
 
     setWidget (container);
 
-    connect (this, SIGNAL (open_file (const QString&)),
-             main_win (), SLOT (open_file (const QString&)));
-
-    connect (this, SIGNAL (displayed_directory_changed (const QString&)),
-             main_win (),
-             SLOT (set_current_working_directory (const QString&)));
-
-    connect (this,
-             SIGNAL (modify_path_signal (const octave_value_list&, bool, bool)),
-             main_win (),
-             SLOT (modify_path (const octave_value_list&, bool, bool)));
-
     // Create a toolbar
     m_navigation_tool_bar = new QToolBar ("", container);
     m_navigation_tool_bar->setAllowedAreas (Qt::TopToolBarArea);
@@ -165,29 +152,29 @@ namespace octave
     popdown_menu->addSeparator ();
     popdown_menu->addAction (rmgr.icon ("folder"),
                              tr ("Set Browser Directory..."),
-                             this, SLOT (popdownmenu_search_dir (bool)));
+                             this, &files_dock_widget::popdownmenu_search_dir);
     popdown_menu->addSeparator ();
     popdown_menu->addAction (rmgr.icon ("edit-find"),
                              tr ("Find Files..."),
-                             this, SLOT (popdownmenu_findfiles (bool)));
+                             this, &files_dock_widget::popdownmenu_findfiles);
     popdown_menu->addSeparator ();
     popdown_menu->addAction (rmgr.icon ("document-new"),
                              tr ("New File..."),
-                             this, SLOT (popdownmenu_newfile (bool)));
+                             this, &files_dock_widget::popdownmenu_newfile);
     popdown_menu->addAction (rmgr.icon ("folder-new"),
                              tr ("New Directory..."),
-                             this, SLOT (popdownmenu_newdir (bool)));
+                             this, &files_dock_widget::popdownmenu_newdir);
 
     m_navigation_tool_bar->addWidget (m_current_directory);
     m_navigation_tool_bar->addAction (directory_up_action);
     m_navigation_tool_bar->addWidget (popdown_button);
 
-    connect (directory_up_action, SIGNAL (triggered ()), this,
-             SLOT (change_directory_up ()));
-    connect (m_sync_octave_directory_action, SIGNAL (triggered ()), this,
-             SLOT (do_sync_octave_directory ()));
-    connect (m_sync_browser_directory_action, SIGNAL (triggered ()), this,
-             SLOT (do_sync_browser_directory ()));
+    connect (directory_up_action, &QAction::triggered,
+             this, &files_dock_widget::change_directory_up);
+    connect (m_sync_octave_directory_action, &QAction::triggered,
+             this, &files_dock_widget::do_sync_octave_directory);
+    connect (m_sync_browser_directory_action, &QAction::triggered,
+             this, &files_dock_widget::do_sync_browser_directory);
 
     gui_settings *settings = rmgr.get_settings ();
     // FIXME: what should happen if settings is 0?
@@ -218,7 +205,7 @@ namespace octave
     m_file_system_model = new QFileSystemModel (this);
     m_file_system_model->setResolveSymlinks (false);
     m_file_system_model->setFilter (
-        QDir::System | QDir::NoDotAndDotDot | QDir::AllEntries);
+      QDir::System | QDir::NoDotAndDotDot | QDir::AllEntries);
     QModelIndex rootPathIndex
       = m_file_system_model->setRootPath (startup_dir.absolutePath ());
 
@@ -245,16 +232,8 @@ namespace octave
         (settings->value (fb_column_state.key).toByteArray ());
 
     // Set header properties for sorting
-#if defined (HAVE_QHEADERVIEW_SETSECTIONSCLICKABLE)
     m_file_tree_view->header ()->setSectionsClickable (true);
-#else
-    m_file_tree_view->header ()->setClickable (true);
-#endif
-#if defined (HAVE_QHEADERVIEW_SETSECTIONSMOVABLE)
     m_file_tree_view->header ()->setSectionsMovable (true);
-#else
-    m_file_tree_view->header ()->setMovable (true);
-#endif
     m_file_tree_view->header ()->setSortIndicatorShown (true);
 
     QStringList mru_dirs =
@@ -264,19 +243,18 @@ namespace octave
     m_current_directory->setEditText
       (m_file_system_model->fileInfo (rootPathIndex). absoluteFilePath ());
 
-    connect (m_file_tree_view, SIGNAL (activated (const QModelIndex &)),
-             this, SLOT (item_double_clicked (const QModelIndex &)));
+    connect (m_file_tree_view, &FileTreeViewer::activated,
+             this, &files_dock_widget::item_double_clicked);
 
     // add context menu to tree_view
     m_file_tree_view->setContextMenuPolicy (Qt::CustomContextMenu);
-    connect (m_file_tree_view,
-             SIGNAL (customContextMenuRequested (const QPoint &)),
-             this, SLOT (contextmenu_requested (const QPoint &)));
+    connect (m_file_tree_view, &FileTreeViewer::customContextMenuRequested,
+             this, &files_dock_widget::contextmenu_requested);
 
     m_file_tree_view->header ()->setContextMenuPolicy (Qt::CustomContextMenu);
     connect (m_file_tree_view->header (),
-             SIGNAL (customContextMenuRequested (const QPoint &)),
-             this, SLOT (headercontextmenu_requested (const QPoint &)));
+             &QHeaderView::customContextMenuRequested,
+             this, &files_dock_widget::headercontextmenu_requested);
 
     // Layout the widgets vertically with the toolbar on top
     QVBoxLayout *vbox_layout = new QVBoxLayout ();
@@ -290,14 +268,26 @@ namespace octave
     // FIXME: Add right-click contextual menus for copying, pasting,
     //        deleting files (and others).
 
-    connect (m_current_directory->lineEdit (), SIGNAL (returnPressed ()),
-             this, SLOT (accept_directory_line_edit ()));
+    connect (m_current_directory->lineEdit (), &QLineEdit::returnPressed,
+             this, &files_dock_widget::accept_directory_line_edit);
 
-    connect (m_current_directory, SIGNAL (activated (const QString &)),
-             this, SLOT (set_current_directory (const QString &)));
+    // FIXME: We could use
+    //
+    //    connect (m_current_directory,
+    //             QOverload<const QString&>::of (&QComboBox::activated),
+    //             this, &files_dock_widget::set_current_directory);
+    //
+    // but referring to QComboBox::activated will generate deprecated
+    // function warnings from GCC.  We could also use
+    //
+    //    connect (m_current_directory, &QComboBox::textActivated,
+    //             this, &files_dock_widget::set_current_directory);
+    //
+    // but the function textActivated was not introduced until Qt 5.14
+    // so we'll need a feature test.
 
-    connect (this, SIGNAL (run_file_signal (const QFileInfo&)),
-             main_win (), SLOT (run_file_in_terminal (const QFileInfo&)));
+    connect (m_current_directory, SIGNAL (activated (const QString&)),
+             this, SLOT (set_current_directory (const QString&)));
 
     QCompleter *completer = new QCompleter (m_file_system_model, this);
     m_current_directory->setCompleter (completer);
@@ -306,6 +296,9 @@ namespace octave
 
     m_sync_octave_dir = true;   // default, overwritten with notice_settings ()
     m_octave_dir = "";
+
+    if (! p)
+      make_window ();
   }
 
   void files_dock_widget::save_settings (void)
@@ -374,14 +367,14 @@ namespace octave
 
   void files_dock_widget::do_sync_browser_directory (void)
   {
-    display_directory (m_octave_dir,false);  // false: no sync of octave dir
+    display_directory (m_octave_dir, false); // false: no sync of octave dir
   }
 
   void files_dock_widget::update_octave_directory (const QString& dir)
   {
     m_octave_dir = dir;
     if (m_sync_octave_dir)
-      display_directory (m_octave_dir,false);  // false: no sync of octave dir
+      display_directory (m_octave_dir, false); // false: no sync of octave dir
   }
 
   void files_dock_widget::display_directory (const QString& dir,
@@ -417,8 +410,11 @@ namespace octave
             resource_manager& rmgr = m_octave_qobj.get_resource_manager ();
             gui_settings *settings = rmgr.get_settings ();
             QString ext = settings->value (fb_txt_file_ext).toString ();
+#if defined (HAVE_QT_SPLITBEHAVIOR_ENUM)
+            QStringList extensions = ext.split (";", Qt::SkipEmptyParts);
+#else
             QStringList extensions = ext.split (";", QString::SkipEmptyParts);
-
+#endif
             if (QFile::exists (abs_fname))
               {
                 if (extensions.contains (suffix))
@@ -446,7 +442,7 @@ namespace octave
     gui_settings *settings = rmgr.get_settings ();
 
     QString key = m_columns_shown_keys.at (col);
-    bool shown = settings->value (key,false).toBool ();
+    bool shown = settings->value (key, false).toBool ();
     settings->setValue (key, ! shown);
     settings->sync ();
 
@@ -488,6 +484,20 @@ namespace octave
                             m_columns_shown_defs.at (i)).toBool ());
       }
 
+    // FIXME: We could use
+    //
+    //   connect (&m_sig_mapper, QOverload<int>::of (&QSignalMapper::mapped),
+    //            this, &workspace_view::toggle_header);
+    //
+    // but referring to QSignalMapper::mapped will generate deprecated
+    // function warnings from GCC.  We could also use
+    //
+    //   connect (&m_sig_mapper, &QSignalMapper::mappedInt,
+    //            this, &workspace_view::toggle_header);
+    //
+    // but the function mappedInt was not introduced until Qt 5.15 so
+    // we'll need a feature test.
+
     connect (m_sig_mapper, SIGNAL (mapped (int)),
              this, SLOT (toggle_header (int)));
 
@@ -522,70 +532,68 @@ namespace octave
 
         // construct the context menu depending on item
         menu.addAction (rmgr.icon ("document-open"), tr ("Open"),
-                        this, SLOT (contextmenu_open (bool)));
+                        this, &files_dock_widget::contextmenu_open);
 
         if (info.isDir ())
           {
             menu.addAction (tr ("Open in System File Explorer"),
-                            this, SLOT (contextmenu_open_in_app (bool)));
+                            this, &files_dock_widget::contextmenu_open_in_app);
           }
 
         if (info.isFile ())
           menu.addAction (tr ("Open in Text Editor"),
-                          this, SLOT (contextmenu_open_in_editor (bool)));
+                          this, &files_dock_widget::contextmenu_open_in_editor);
 
         menu.addAction (tr ("Copy Selection to Clipboard"),
-                        this, SLOT (contextmenu_copy_selection (bool)));
+                        this, &files_dock_widget::contextmenu_copy_selection);
 
         if (info.isFile () && info.suffix () == "m")
-          menu.addAction (rmgr.icon ("media-playback-start"),
-                          tr ("Run"), this, SLOT (contextmenu_run (bool)));
+          menu.addAction (rmgr.icon ("media-playback-start"), tr ("Run"),
+                          this, &files_dock_widget::contextmenu_run);
 
         if (info.isFile ())
-          menu.addAction (tr ("Load Data"), this, SLOT (contextmenu_load (bool)));
+          menu.addAction (tr ("Load Data"),
+                          this, &files_dock_widget::contextmenu_load);
 
         if (info.isDir ())
           {
             menu.addSeparator ();
-            menu.addAction (rmgr.icon ("go-first"),
-                            tr ("Set Current Directory"),
-                            this, SLOT (contextmenu_setcurrentdir (bool)));
+            menu.addAction (rmgr.icon ("go-first"), tr ("Set Current Directory"),
+                            this, &files_dock_widget::contextmenu_setcurrentdir);
 
             QMenu *add_path_menu = menu.addMenu (tr ("Add to Path"));
 
             add_path_menu->addAction (tr ("Selected Directories"),
-                                      this, SLOT (contextmenu_add_to_path (bool)));
+                                      this, [=] (bool checked) { contextmenu_add_to_path (checked); });
             add_path_menu->addAction (tr ("Selected Directories and Subdirectories"),
-                                      this, SLOT (contextmenu_add_to_path_subdirs (bool)));
+                                      this, &files_dock_widget::contextmenu_add_to_path_subdirs);
 
             QMenu *rm_path_menu = menu.addMenu (tr ("Remove from Path"));
 
-            rm_path_menu->addAction (tr ("Selected Directories"), this,
-                                     SLOT (contextmenu_rm_from_path (bool)));
+            rm_path_menu->addAction (tr ("Selected Directories"),
+                                     this, &files_dock_widget::contextmenu_rm_from_path);
             rm_path_menu->addAction (tr ("Selected Directories and Subdirectories"),
-                                     this, SLOT (contextmenu_rm_from_path_subdirs (bool)));
+                                     this, &files_dock_widget::contextmenu_rm_from_path_subdirs);
 
             menu.addSeparator ();
 
-            menu.addAction (rmgr.icon ("edit-find"),
-                            tr ("Find Files..."), this,
-                            SLOT (contextmenu_findfiles (bool)));
+            menu.addAction (rmgr.icon ("edit-find"), tr ("Find Files..."),
+                            this, &files_dock_widget::contextmenu_findfiles);
           }
 
         menu.addSeparator ();
-        menu.addAction (tr ("Rename..."), this, SLOT (contextmenu_rename (bool)));
-        menu.addAction (rmgr.icon ("edit-delete"),
-                        tr ("Delete..."), this, SLOT (contextmenu_delete (bool)));
+        menu.addAction (tr ("Rename..."),
+                        this, &files_dock_widget::contextmenu_rename);
+        menu.addAction (rmgr.icon ("edit-delete"), tr ("Delete..."),
+                        this, &files_dock_widget::contextmenu_delete);
 
         if (info.isDir ())
           {
             menu.addSeparator ();
-            menu.addAction (rmgr.icon ("document-new"),
-                            tr ("New File..."),
-                            this, SLOT (contextmenu_newfile (bool)));
-            menu.addAction (rmgr.icon ("folder-new"),
-                            tr ("New Directory..."),
-                            this, SLOT (contextmenu_newdir (bool)));
+            menu.addAction (rmgr.icon ("document-new"), tr ("New File..."),
+                            this, &files_dock_widget::contextmenu_newfile);
+            menu.addAction (rmgr.icon ("folder-new"), tr ("New Directory..."),
+                            this, &files_dock_widget::contextmenu_newdir);
           }
 
         // show the menu
@@ -706,6 +714,10 @@ namespace octave
             // Do the renaming
             QFile f (old_name);  // Must use QFile, not QDir (bug #56298)
             bool st = f.rename (new_name);
+            if (! st)
+              QMessageBox::warning (this, tr ("Rename error"),
+                                    tr ("Could not rename file \"%1\" to \"%2\".").
+                                    arg (old_name).arg (new_name));
             // editor: load new/old file depending on success
             emit file_renamed_signal (st);
             // Clear cache of file browser
@@ -720,17 +732,38 @@ namespace octave
     QItemSelectionModel *m = m_file_tree_view->selectionModel ();
     QModelIndexList rows = m->selectedRows ();
 
+    int file_cnt = rows.size ();
+    bool multiple_files = (file_cnt > 1);
+
     for (auto it = rows.begin (); it != rows.end (); it++)
       {
         QModelIndex index = *it;
 
         QFileInfo info = m_file_system_model->fileInfo (index);
 
-        if (QMessageBox::question (this, tr ("Delete file/directory"),
-                                   tr ("Are you sure you want to delete\n")
-                                   + info.filePath (),
-                                   QMessageBox::Yes | QMessageBox::No)
-            == QMessageBox::Yes)
+        QMessageBox::StandardButton dlg_answer;
+        if (multiple_files)
+          if (it == rows.begin ())
+            {
+              dlg_answer = QMessageBox::question (this,
+                                                  tr ("Delete file/directory"),
+                                                  tr ("Are you sure you want to delete all %1 selected files?\n").arg (file_cnt),
+                                                  QMessageBox::Yes | QMessageBox::No);
+              if (dlg_answer != QMessageBox::Yes)
+                return;
+            }
+          else
+            dlg_answer = QMessageBox::Yes;
+        else
+          {
+            dlg_answer = QMessageBox::question (this,
+                           tr ("Delete file/directory"),
+                           tr ("Are you sure you want to delete\n")
+                           + info.filePath (),
+                           QMessageBox::Yes | QMessageBox::No);
+          }
+
+        if (dlg_answer)
           {
             if (info.isDir ())
               {
@@ -752,9 +785,14 @@ namespace octave
                 emit file_remove_signal (info.filePath (), QString ());
                 // Remove the file.
                 bool st = m_file_system_model->remove (index);
-                // Reload the old file if removing was not successful
                 if (! st)
-                  emit file_renamed_signal (false);
+                  {
+                    QMessageBox::warning (this, tr ("Deletion error"),
+                                          tr ("Could not delete file \"%1\".").
+                                          arg (info.filePath ()));
+                    // Reload the old file
+                    emit file_renamed_signal (false);
+                  }
               }
 
             m_file_system_model->revert ();
@@ -830,10 +868,10 @@ namespace octave
   {
     QList<QFileInfo> infos = get_selected_items_info (true);
 
-    octave_value_list dir_list = ovl ();
+    QStringList dir_list;
 
     for (int i = 0; i < infos.length (); i++)
-      dir_list.append (infos.at (i).absoluteFilePath ().toStdString ());
+      dir_list.append (infos.at (i).absoluteFilePath ());
 
     if (infos.length () > 0)
       emit modify_path_signal (dir_list, rm, subdirs);
@@ -881,7 +919,7 @@ namespace octave
 
     QStyle *st = style ();
     int icon_size = st->pixelMetric (global_icon_sizes[size_idx]);
-    m_navigation_tool_bar->setIconSize (QSize (icon_size,icon_size));
+    m_navigation_tool_bar->setIconSize (QSize (icon_size, icon_size));
 
     // filenames are always shown, other columns can be hidden by settings
     for (int i = 0; i < 3; i++)
@@ -889,7 +927,7 @@ namespace octave
                                          ! settings->value (m_columns_shown_keys.at (i),false).toBool ());
 
     QDir::Filters current_filter = m_file_system_model->filter ();
-    if (settings->value (m_columns_shown_keys.at (3),false).toBool ())
+    if (settings->value (m_columns_shown_keys.at (3), false).toBool ())
       m_file_system_model->setFilter (current_filter | QDir::Hidden);
     else
       m_file_system_model->setFilter (current_filter & (~QDir::Hidden));
@@ -961,7 +999,7 @@ namespace octave
     bool ok;
 
     QString name = QInputDialog::getText (this, tr ("Create File"),
-                                          tr ("Create file in\n","String ends with \\n!") + parent_dir,
+                                          tr ("Create file in\n", "String ends with \\n!") + parent_dir,
                                           QLineEdit::Normal,
                                           tr ("New File.txt"), &ok);
     if (ok && name.length () > 0)
@@ -979,7 +1017,7 @@ namespace octave
     bool ok;
 
     QString name = QInputDialog::getText (this, tr ("Create Directory"),
-                                          tr ("Create folder in\n","String ends with \\n!") + parent_dir,
+                                          tr ("Create folder in\n", "String ends with \\n!") + parent_dir,
                                           QLineEdit::Normal,
                                           tr ("New Directory"), &ok);
     if (ok && name.length () > 0)
@@ -990,12 +1028,12 @@ namespace octave
       }
   }
 
-  void files_dock_widget::process_set_current_dir (const QString & dir)
+  void files_dock_widget::process_set_current_dir (const QString& dir)
   {
     emit displayed_directory_changed (dir);
   }
 
-  void files_dock_widget::process_find_files (const QString & dir)
+  void files_dock_widget::process_find_files (const QString& dir)
   {
     emit find_files_signal (dir);
   }
