@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2012-2021 The Octave Project Developers
+// Copyright (C) 2012-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -41,6 +41,7 @@
 #include "gui-preferences-mw.h"
 #include "gui-preferences-sc.h"
 #include "gui-settings.h"
+#include "main-window.h"
 #include "octave-dock-widget.h"
 #include "octave-qobject.h"
 
@@ -79,7 +80,7 @@ namespace octave
     m_dock_button = new QToolButton (m_title_widget);
     m_dock_button->setDefaultAction (m_dock_action);
     m_dock_button->setFocusPolicy (Qt::NoFocus);
-    m_dock_button->setIconSize (QSize (m_icon_size,m_icon_size));
+    m_dock_button->setIconSize (QSize (m_icon_size, m_icon_size));
 
     m_close_action = new QAction
       (QIcon (":/actions/icons/widget-close.png"), "", this);
@@ -87,7 +88,7 @@ namespace octave
     m_close_button = new QToolButton (m_title_widget);
     m_close_button->setDefaultAction (m_close_action);
     m_close_button->setFocusPolicy (Qt::NoFocus);
-    m_close_button->setIconSize (QSize (m_icon_size,m_icon_size));
+    m_close_button->setIconSize (QSize (m_icon_size, m_icon_size));
 
     QString css_button = QString ("QToolButton {background: transparent; border: 0px;}");
     m_dock_button->setStyleSheet (css_button);
@@ -98,20 +99,24 @@ namespace octave
     h_layout->addWidget (m_dock_button);
     h_layout->addWidget (m_close_button);
     h_layout->setSpacing (10);
-    h_layout->setContentsMargins (5,2,2,2);
+    h_layout->setContentsMargins (5, 2, 2, 2);
 
     m_title_widget->setLayout (h_layout);
 
-    // copy & paste handling
-    connect (p, SIGNAL (copyClipboard_signal ()),
-             this, SLOT (copyClipboard ()));
-    connect (p, SIGNAL (pasteClipboard_signal ()),
-             this, SLOT (pasteClipboard ()));
-    connect (p, SIGNAL (selectAll_signal ()),
-             this, SLOT (selectAll ()));
+    if (p && (p->objectName () == gui_obj_name_main_window))
+      {
+        // Only connect the when a parent (main window) is given
+        // copy & paste handling
+        connect (p, SIGNAL (copyClipboard_signal ()),
+                 this, SLOT (copyClipboard ()));
+        connect (p, SIGNAL (pasteClipboard_signal ()),
+                 this, SLOT (pasteClipboard ()));
+        connect (p, SIGNAL (selectAll_signal ()),
+                 this, SLOT (selectAll ()));
 
-    // undo handling
-    connect (p, SIGNAL (undo_signal ()), this, SLOT (do_undo ()));
+        // undo handling
+        connect (p, SIGNAL (undo_signal ()), this, SLOT (do_undo ()));
+      }
   }
 
   // set the title in the dockwidgets title bar
@@ -122,7 +127,7 @@ namespace octave
       = static_cast<QHBoxLayout *> (m_title_widget->layout ());
     QLabel *label = new QLabel (title, m_title_widget);
     label->setStyleSheet ("background-color: transparent;");
-    h_layout->insertWidget (0,label);
+    h_layout->insertWidget (0, label);
     setTitleBarWidget (m_title_widget);
     setWindowTitle (title);
   }
@@ -183,59 +188,46 @@ namespace octave
 
   octave_dock_widget::octave_dock_widget (const QString& obj_name, QWidget *p,
                                           base_qobject& oct_qobj)
-    : label_dock_widget (p, oct_qobj), m_recent_float_geom (),
-      m_recent_dock_geom (), m_waiting_for_mouse_button_release (false)
+    : label_dock_widget (p, oct_qobj), m_adopted (false),
+      m_custom_style (false), m_focus_follows_mouse (false),
+      m_recent_float_geom (), m_recent_dock_geom (),
+      m_waiting_for_mouse_button_release (false)
   {
     setObjectName (obj_name);
 
-    m_parent = static_cast<QMainWindow *> (p);     // store main window
+    // FIXME: Can we avoid the cast here?
+    m_main_window = dynamic_cast<main_window *> (p);
+
     m_predecessor_widget = nullptr;
 
-    connect (this, SIGNAL (topLevelChanged (bool)),
-             this, SLOT (toplevel_change (bool)));
-    connect (this, SIGNAL (visibilityChanged (bool)),
-             this, SLOT (handle_visibility_changed (bool)));
-
-    connect (p, SIGNAL (settings_changed (const gui_settings *)),
-             this, SLOT (handle_settings (const gui_settings *)));
-
-    connect (p, SIGNAL (active_dock_changed (octave_dock_widget*,
-                                             octave_dock_widget*)),
-             this, SLOT (handle_active_dock_changed (octave_dock_widget*,
-                                                     octave_dock_widget*)));
+    connect (this, &octave_dock_widget::topLevelChanged,
+             this, &octave_dock_widget::toplevel_change);
+    connect (this, &octave_dock_widget::visibilityChanged,
+             this, &octave_dock_widget::handle_visibility);
 
     if (m_default_float_button != nullptr)
       {
         disconnect (m_default_float_button, 0, 0, 0);
-        connect (m_default_float_button, SIGNAL (clicked (bool)),
-                 this, SLOT (make_window (bool)));
+        connect (m_default_float_button, &QAbstractButton::clicked,
+                 this, &octave_dock_widget::make_window);
       }
-    connect (this, SIGNAL (queue_make_window (bool)),
-             this, SLOT (make_window (bool)), Qt::QueuedConnection);
-    connect (this, SIGNAL (queue_make_widget ()),
-             this, SLOT (make_widget ()), Qt::QueuedConnection);
+    connect (this, &octave_dock_widget::queue_make_window,
+             this, &octave_dock_widget::make_window, Qt::QueuedConnection);
+    connect (this, &octave_dock_widget::queue_make_widget,
+             this, [=] () { make_widget (); }, Qt::QueuedConnection);
 
     shortcut_manager& scmgr = m_octave_qobj.get_shortcut_manager ();
     scmgr.set_shortcut (m_dock_action, sc_dock_widget_dock);
     m_dock_action->setShortcutContext (Qt::WidgetWithChildrenShortcut);
     addAction (m_dock_action);
-    connect (m_dock_action, SIGNAL (triggered (bool)),
-             this, SLOT (make_window (bool)));
+    connect (m_dock_action, &QAction::triggered,
+             this, &octave_dock_widget::make_window);
 
     scmgr.set_shortcut (m_close_action, sc_dock_widget_close);
     m_close_action->setShortcutContext (Qt::WidgetWithChildrenShortcut);
     addAction (m_close_action);
-    connect (m_close_action, SIGNAL (triggered (bool)),
-             this, SLOT (change_visibility (bool)));
-
-    // Any interpreter_event signal from an octave_dock_widget object is
-    // handled the same as for the parent main_window object.
-
-    connect (this, SIGNAL (interpreter_event (const fcn_callback&)),
-             p, SIGNAL (interpreter_event (const fcn_callback&)));
-
-    connect (this, SIGNAL (interpreter_event (const meth_callback&)),
-             p, SIGNAL (interpreter_event (const meth_callback&)));
+    connect (m_close_action, &QAction::triggered,
+             this, &octave_dock_widget::change_visibility);
 
     m_close_action->setToolTip (tr ("Hide widget"));
 
@@ -256,18 +248,17 @@ namespace octave
 
     setFocusPolicy (Qt::StrongFocus);
 
-    setFeatures (QDockWidget::AllDockWidgetFeatures);
+    setFeatures (QDockWidget::DockWidgetClosable
+                 | QDockWidget::DockWidgetMovable
+                 | QDockWidget::DockWidgetFloatable);
 
     resource_manager& rmgr = m_octave_qobj.get_resource_manager ();
     handle_settings (rmgr.get_settings ());
   }
 
-  // connect signal visibility changed to related slot (called from main-window)
   void
-  octave_dock_widget::connect_visibility_changed (void)
+  octave_dock_widget::init_window_menu_entry (void)
   {
-    connect (this, SIGNAL (visibilityChanged (bool)),
-             this, SLOT (handle_visibility (bool)));
     emit active_changed (isVisible ());  // emit once for init of window menu
   }
 
@@ -291,10 +282,14 @@ namespace octave
     if (isFloating ())
       setFloating (false);
 
-    // Before making it a separate (no more parent) floating widget, remove
-    // the dock widget from the main window. This ensures that tabbed widgets
-    // keep their focus when it is re-docked later
-    m_parent->removeDockWidget (this);
+    if (m_main_window)
+      {
+        // Before making it a separate (no more parent) floating widget,
+        // remove the dock widget from the main window. This ensures
+        // that tabbed widgets keep their focus when it is re-docked
+        // later
+        m_main_window->removeDockWidget (this);
+      }
 
     setParent (0, Qt::CustomizeWindowHint | Qt::WindowTitleHint |
                Qt::WindowMinMaxButtonsHint | Qt::WindowCloseButtonHint | Qt::Window);
@@ -308,8 +303,8 @@ namespace octave
 
     // adjust the (un)dock action
     disconnect (m_dock_action, 0, this, 0);
-    connect (m_dock_action, SIGNAL (triggered (bool)),
-             this, SLOT (make_widget (bool)));
+    connect (m_dock_action, &QAction::triggered,
+             this, &octave_dock_widget::make_widget);
 
     // adjust the (un)dock icon
     if (titleBarWidget ())
@@ -321,8 +316,8 @@ namespace octave
     else
       {
         disconnect (m_default_float_button, 0, this, 0);
-        connect (m_default_float_button, SIGNAL (clicked (bool)),
-                 this, SLOT (make_widget (bool)));
+        connect (m_default_float_button, &QAbstractButton::clicked,
+                 this, &octave_dock_widget::make_widget);
       }
 
     raise ();
@@ -348,22 +343,29 @@ namespace octave
     resource_manager& rmgr = m_octave_qobj.get_resource_manager ();
     gui_settings *settings = rmgr.get_settings ();
 
-    settings->setValue (mw_state.key, m_parent->saveState ());
-    // Stay window, otherwise will bounce back to window by default because
-    // there is no layout information for this widget in the saved settings.
-    setParent (m_parent, Qt::Window);
-    m_parent->addDockWidget (Qt::BottomDockWidgetArea, this);
-    // recover old window states, hide and re-show new added widget
-    m_parent->restoreState (settings->value (mw_state.key).toByteArray ());
-    setFloating (false);
-    // restore size using setGeometry instead of restoreGeometry following
-    // this post:
-    // https://forum.qt.io/topic/79326/qdockwidget-restoregeometry-not-working-correctly-when-qmainwindow-is-maximized/5
-    setGeometry (m_recent_dock_geom);
+    if (m_main_window)
+      {
+        settings->setValue (mw_state.key, m_main_window->saveState ());
+
+        // Stay window, otherwise will bounce back to window by default
+        // because there is no layout information for this widget in the
+        // saved settings.
+        setParent (m_main_window, Qt::Window);
+        m_main_window->addDockWidget (Qt::BottomDockWidgetArea, this);
+        m_adopted = false;
+        // recover old window states, hide and re-show new added widget
+        m_main_window->restoreState (settings->value (mw_state.key).toByteArray ());
+        setFloating (false);
+        // restore size using setGeometry instead of restoreGeometry
+        // following this post:
+        // https://forum.qt.io/topic/79326/qdockwidget-restoregeometry-not-working-correctly-when-qmainwindow-is-maximized/5
+        setGeometry (m_recent_dock_geom);
+      }
 
     // adjust the (un)dock icon
-    connect (m_dock_action, SIGNAL (triggered (bool)),
-             this, SLOT (make_window (bool)));
+    disconnect (m_dock_action, 0, this, 0);
+    connect (m_dock_action, &QAction::triggered,
+             this, &octave_dock_widget::make_window);
     if (titleBarWidget ())
       {
         m_dock_action->setIcon (QIcon (":/actions/icons/widget-undock"
@@ -373,8 +375,8 @@ namespace octave
     else
       {
         disconnect (m_default_float_button, 0, this, 0);
-        connect (m_default_float_button, SIGNAL (clicked (bool)),
-                 this, SLOT (make_window (bool)));
+        connect (m_default_float_button, &QAbstractButton::clicked,
+                 this, &octave_dock_widget::make_window);
       }
 
     raise ();
@@ -402,6 +404,27 @@ namespace octave
     m_predecessor_widget = prev_widget;
   }
 
+  void
+  octave_dock_widget::set_main_window (main_window *mw)
+  {
+    m_main_window = mw;
+
+    if (m_main_window)
+      {
+        connect (m_main_window, &main_window::copyClipboard_signal,
+                 this, &octave_dock_widget::copyClipboard);
+
+        connect (m_main_window, &main_window::pasteClipboard_signal,
+                 this, &octave_dock_widget::pasteClipboard);
+
+        connect (m_main_window, &main_window::selectAll_signal,
+                 this, &octave_dock_widget::selectAll);
+
+        connect (m_main_window, &main_window::undo_signal,
+                 this, &octave_dock_widget::do_undo);
+      }
+  }
+
   // close event
   void
   octave_dock_widget::closeEvent (QCloseEvent *e)
@@ -446,6 +469,11 @@ namespace octave
   void
   octave_dock_widget::handle_settings (const gui_settings *settings)
   {
+    if (! settings)
+      return;
+
+    m_focus_follows_mouse = settings->value (dw_focus_follows_mouse).toBool ();
+
     m_custom_style
       = settings->value (dw_title_custom_style).toBool ();
 
@@ -484,12 +512,27 @@ namespace octave
     else
       m_icon_color_active = "";
 
-    QRect available_size = QApplication::desktop ()->availableGeometry (m_parent);
+
+    QWidget *ref_widget = m_main_window;
+    if (! ref_widget)
+      ref_widget = this;
+
     int x, y, w, h;
-    available_size.getRect (&x, &y, &w, &h);
+    QApplication::desktop ()->availableGeometry (ref_widget).getRect (&x, &y, &w, &h);
     QRect default_floating_size = QRect (x+16, y+32, w/3, h/2);
-    m_parent->geometry ().getRect (&x, &y, &w, &h);
-    QRect default_dock_size = QRect (x+16, y+32, w/3, h/3);
+
+    QRect default_dock_size;
+    if (m_main_window)
+      {
+        // We have a main window, dock size depends on size of main window
+        m_main_window->geometry ().getRect (&x, &y, &w, &h);
+        default_dock_size = QRect (x+16, y+32, w/3, h/3);
+      }
+    else
+      {
+        // No main window, default dock size should never be used
+        default_dock_size = QRect (0, 0, w/10, h/10);
+      }
 
     m_recent_float_geom
       = settings->value (dw_float_geometry.key.arg (objectName ()),
@@ -507,12 +550,7 @@ namespace octave
     QVariant dock_geom
       = settings->value (dw_dock_geometry.key.arg (objectName ()),
                          default_dock_size);
-#if defined (QVARIANT_CANCONVERT_ACCEPTS_QMETATYPE_TYPE)
-    QMetaType::Type rect_type = QMetaType::QRect;
-#else
-    QVariant::Type rect_type = QVariant::Rect;
-#endif
-    if (dock_geom.canConvert (rect_type))
+    if (dock_geom.canConvert (QMetaType::QRect))
       m_recent_dock_geom = dock_geom.toRect ();
     else
       m_recent_dock_geom = dw_dock_geometry.def.toRect ();
@@ -522,11 +560,11 @@ namespace octave
     set_style (false);
 
     // Compacter design
-    QToolBar* toolbar = findChild <QToolBar *> ();
+    QToolBar *toolbar = findChild <QToolBar *> ();
     if (toolbar)
       toolbar->setStyleSheet (toolbar->styleSheet () + global_toolbar_style);
 
-    QMenuBar* menubar = findChild <QMenuBar *> ();
+    QMenuBar *menubar = findChild <QMenuBar *> ();
     if (menubar)
       menubar->setStyleSheet (menubar->styleSheet () + global_menubar_style);
 
@@ -577,13 +615,20 @@ namespace octave
 
   bool octave_dock_widget::eventFilter (QObject *obj, QEvent *e)
   {
+    // Ignore double clicks into window decoration elements
     if (e->type () == QEvent::NonClientAreaMouseButtonDblClick)
       {
-        e->ignore (); // ignore double clicks into window decoration elements
+        e->ignore ();
         return true;
       }
 
-    return QDockWidget::eventFilter (obj,e);
+    // Detect mouse enter events if "focus follows mouse" is desired
+    // for widgets docked to the main window (non floating) and activate
+    // the widget currently under the mouse
+    if (m_focus_follows_mouse && ! isFloating () && (e->type () == QEvent::Enter))
+      setFocus ();
+
+    return QDockWidget::eventFilter (obj, e);
   }
 
   void
@@ -636,8 +681,12 @@ namespace octave
 
   void octave_dock_widget::handle_visibility (bool visible)
   {
-    if (visible && ! isFloating ())
-      setFocus ();
+    if (visible)
+      {
+        emit active_changed (true);
+        if (! isFloating ())
+          setFocus ();
+      }
   }
 
   void
