@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2021 The Octave Project Developers
+// Copyright (C) 1996-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -41,6 +41,8 @@
 #include "ov.h"
 #include "ovl.h"
 
+OCTAVE_NAMESPACE_BEGIN
+
 template <typename CHOLT>
 static octave_value
 get_chol (const CHOLT& fact)
@@ -146,7 +148,8 @@ $ R^T R = A (Q, Q)$.
 
 In general the lower triangular factorization is significantly faster for
 sparse matrices.
-@seealso{hess, lu, qr, qz, schur, svd, ichol, cholinv, chol2inv, cholupdate, cholinsert, choldelete, cholshift}
+@seealso{hess, lu, qr, qz, schur, svd, ichol, cholinv, chol2inv, cholupdate,
+cholinsert, choldelete, cholshift}
 @end deftypefn */)
 {
   int nargin = args.length ();
@@ -164,11 +167,11 @@ sparse matrices.
     {
       std::string tmp = args(n++).xstring_value ("chol: optional arguments must be strings");
 
-      if (octave::string::strcmpi (tmp, "vector"))
+      if (string::strcmpi (tmp, "vector"))
         vecout = true;
-      else if (octave::string::strcmpi (tmp, "lower"))
+      else if (string::strcmpi (tmp, "lower"))
         LLt = true;
-      else if (octave::string::strcmpi (tmp, "upper"))
+      else if (string::strcmpi (tmp, "upper"))
         LLt = false;
       else
         error (R"(chol: optional argument must be one of "vector", "lower", or "upper")");
@@ -190,7 +193,7 @@ sparse matrices.
         {
           SparseMatrix m = arg.sparse_matrix_value ();
 
-          octave::math::sparse_chol<SparseMatrix> fact (m, info, natural, force);
+          math::sparse_chol<SparseMatrix> fact (m, info, natural, force);
 
           if (nargout == 3)
             {
@@ -215,7 +218,7 @@ sparse matrices.
         {
           SparseComplexMatrix m = arg.sparse_complex_matrix_value ();
 
-          octave::math::sparse_chol<SparseComplexMatrix> fact (m, info, natural, force);
+          math::sparse_chol<SparseComplexMatrix> fact (m, info, natural, force);
 
           if (nargout == 3)
             {
@@ -249,7 +252,7 @@ sparse matrices.
 
           octave_idx_type info;
 
-          octave::math::chol<FloatMatrix> fact (m, info, LLt != true);
+          math::chol<FloatMatrix> fact (m, info, LLt != true);
 
           if (nargout == 2 || info == 0)
             retval = ovl (get_chol (fact), info);
@@ -262,7 +265,7 @@ sparse matrices.
 
           octave_idx_type info;
 
-          octave::math::chol<FloatComplexMatrix> fact (m, info, LLt != true);
+          math::chol<FloatComplexMatrix> fact (m, info, LLt != true);
 
           if (nargout == 2 || info == 0)
             retval = ovl (get_chol (fact), info);
@@ -282,7 +285,7 @@ sparse matrices.
 
           octave_idx_type info;
 
-          octave::math::chol<Matrix> fact (m, info, LLt != true);
+          math::chol<Matrix> fact (m, info, LLt != true);
 
           if (nargout == 2 || info == 0)
             retval = ovl (get_chol (fact), info);
@@ -295,7 +298,7 @@ sparse matrices.
 
           octave_idx_type info;
 
-          octave::math::chol<ComplexMatrix> fact (m, info, LLt != true);
+          math::chol<ComplexMatrix> fact (m, info, LLt != true);
 
           if (nargout == 2 || info == 0)
             retval = ovl (get_chol (fact), info);
@@ -383,7 +386,7 @@ the Cholesky@tie{}factorization.
             {
               SparseMatrix m = arg.sparse_matrix_value ();
 
-              octave::math::sparse_chol<SparseMatrix> chol (m, info);
+              math::sparse_chol<SparseMatrix> chol (m, info);
 
               if (info == 0)
                 retval = chol.inverse ();
@@ -394,7 +397,7 @@ the Cholesky@tie{}factorization.
             {
               SparseComplexMatrix m = arg.sparse_complex_matrix_value ();
 
-              octave::math::sparse_chol<SparseComplexMatrix> chol (m, info);
+              math::sparse_chol<SparseComplexMatrix> chol (m, info);
 
               if (info == 0)
                 retval = chol.inverse ();
@@ -411,7 +414,7 @@ the Cholesky@tie{}factorization.
               FloatMatrix m = arg.float_matrix_value ();
 
               octave_idx_type info;
-              octave::math::chol<FloatMatrix> chol (m, info);
+              math::chol<FloatMatrix> chol (m, info);
               if (info == 0)
                 retval = chol.inverse ();
               else
@@ -422,7 +425,7 @@ the Cholesky@tie{}factorization.
               FloatComplexMatrix m = arg.float_complex_matrix_value ();
 
               octave_idx_type info;
-              octave::math::chol<FloatComplexMatrix> chol (m, info);
+              math::chol<FloatComplexMatrix> chol (m, info);
               if (info == 0)
                 retval = chol.inverse ();
               else
@@ -438,7 +441,7 @@ the Cholesky@tie{}factorization.
               Matrix m = arg.matrix_value ();
 
               octave_idx_type info;
-              octave::math::chol<Matrix> chol (m, info);
+              math::chol<Matrix> chol (m, info);
               if (info == 0)
                 retval = chol.inverse ();
               else
@@ -449,7 +452,7 @@ the Cholesky@tie{}factorization.
               ComplexMatrix m = arg.complex_matrix_value ();
 
               octave_idx_type info;
-              octave::math::chol<ComplexMatrix> chol (m, info);
+              math::chol<ComplexMatrix> chol (m, info);
               if (info == 0)
                 retval = chol.inverse ();
               else
@@ -510,13 +513,13 @@ diagonal elements.  @code{chol2inv (@var{U})} provides
             {
               SparseMatrix r = arg.sparse_matrix_value ();
 
-              retval = octave::math::chol2inv (r);
+              retval = math::chol2inv (r);
             }
           else if (arg.iscomplex ())
             {
               SparseComplexMatrix r = arg.sparse_complex_matrix_value ();
 
-              retval = octave::math::chol2inv (r);
+              retval = math::chol2inv (r);
             }
           else
             err_wrong_type_arg ("chol2inv", arg);
@@ -527,13 +530,13 @@ diagonal elements.  @code{chol2inv (@var{U})} provides
             {
               FloatMatrix r = arg.float_matrix_value ();
 
-              retval = octave::math::chol2inv (r);
+              retval = math::chol2inv (r);
             }
           else if (arg.iscomplex ())
             {
               FloatComplexMatrix r = arg.float_complex_matrix_value ();
 
-              retval = octave::math::chol2inv (r);
+              retval = math::chol2inv (r);
             }
           else
             err_wrong_type_arg ("chol2inv", arg);
@@ -545,13 +548,13 @@ diagonal elements.  @code{chol2inv (@var{U})} provides
             {
               Matrix r = arg.matrix_value ();
 
-              retval = octave::math::chol2inv (r);
+              retval = math::chol2inv (r);
             }
           else if (arg.iscomplex ())
             {
               ComplexMatrix r = arg.complex_matrix_value ();
 
-              retval = octave::math::chol2inv (r);
+              retval = math::chol2inv (r);
             }
           else
             err_wrong_type_arg ("chol2inv", arg);
@@ -581,11 +584,11 @@ diagonal elements.  @code{chol2inv (@var{U})} provides
 %! sparse_chol2inv (B, eps*100);
 
 %!testif HAVE_CHOLMOD
-%! C = gallery("tridiag", 5);
+%! C = gallery ("tridiag", 5);
 %! sparse_chol2inv (C, eps*10);
 
 %!testif HAVE_CHOLMOD
-%! D = gallery("wathen", 1, 1);
+%! D = gallery ("wathen", 1, 1);
 %! sparse_chol2inv (D, eps*10^4);
 
 */
@@ -657,7 +660,7 @@ If @var{info} is not present, an error message is printed in cases 1 and 2.
           FloatMatrix R = argr.float_matrix_value ();
           FloatColumnVector u = argu.float_column_vector_value ();
 
-          octave::math::chol<FloatMatrix> fact;
+          math::chol<FloatMatrix> fact;
           fact.set (R);
 
           if (down)
@@ -674,7 +677,7 @@ If @var{info} is not present, an error message is printed in cases 1 and 2.
           FloatComplexColumnVector u
             = argu.float_complex_column_vector_value ();
 
-          octave::math::chol<FloatComplexMatrix> fact;
+          math::chol<FloatComplexMatrix> fact;
           fact.set (R);
 
           if (down)
@@ -693,7 +696,7 @@ If @var{info} is not present, an error message is printed in cases 1 and 2.
           Matrix R = argr.matrix_value ();
           ColumnVector u = argu.column_vector_value ();
 
-          octave::math::chol<Matrix> fact;
+          math::chol<Matrix> fact;
           fact.set (R);
 
           if (down)
@@ -709,7 +712,7 @@ If @var{info} is not present, an error message is printed in cases 1 and 2.
           ComplexMatrix R = argr.complex_matrix_value ();
           ComplexColumnVector u = argu.complex_column_vector_value ();
 
-          octave::math::chol<ComplexMatrix> fact;
+          math::chol<ComplexMatrix> fact;
           fact.set (R);
 
           if (down)
@@ -851,7 +854,7 @@ If @var{info} is not present, an error message is printed in cases 1 and 2.
           FloatMatrix R = argr.float_matrix_value ();
           FloatColumnVector u = argu.float_column_vector_value ();
 
-          octave::math::chol<FloatMatrix> fact;
+          math::chol<FloatMatrix> fact;
           fact.set (R);
           err = fact.insert_sym (u, j-1);
 
@@ -864,7 +867,7 @@ If @var{info} is not present, an error message is printed in cases 1 and 2.
           FloatComplexColumnVector u
             = argu.float_complex_column_vector_value ();
 
-          octave::math::chol<FloatComplexMatrix> fact;
+          math::chol<FloatComplexMatrix> fact;
           fact.set (R);
           err = fact.insert_sym (u, j-1);
 
@@ -879,7 +882,7 @@ If @var{info} is not present, an error message is printed in cases 1 and 2.
           Matrix R = argr.matrix_value ();
           ColumnVector u = argu.column_vector_value ();
 
-          octave::math::chol<Matrix> fact;
+          math::chol<Matrix> fact;
           fact.set (R);
           err = fact.insert_sym (u, j-1);
 
@@ -891,7 +894,7 @@ If @var{info} is not present, an error message is printed in cases 1 and 2.
           ComplexMatrix R = argr.complex_matrix_value ();
           ComplexColumnVector u = argu.complex_column_vector_value ();
 
-          octave::math::chol<ComplexMatrix> fact;
+          math::chol<ComplexMatrix> fact;
           fact.set (R);
           err = fact.insert_sym (u, j-1);
 
@@ -1088,7 +1091,7 @@ triangular, return the Cholesky@tie{}factorization of @w{A(p,p)}, where
           // real case
           FloatMatrix R = argr.float_matrix_value ();
 
-          octave::math::chol<FloatMatrix> fact;
+          math::chol<FloatMatrix> fact;
           fact.set (R);
           fact.delete_sym (j-1);
 
@@ -1099,7 +1102,7 @@ triangular, return the Cholesky@tie{}factorization of @w{A(p,p)}, where
           // complex case
           FloatComplexMatrix R = argr.float_complex_matrix_value ();
 
-          octave::math::chol<FloatComplexMatrix> fact;
+          math::chol<FloatComplexMatrix> fact;
           fact.set (R);
           fact.delete_sym (j-1);
 
@@ -1113,7 +1116,7 @@ triangular, return the Cholesky@tie{}factorization of @w{A(p,p)}, where
           // real case
           Matrix R = argr.matrix_value ();
 
-          octave::math::chol<Matrix> fact;
+          math::chol<Matrix> fact;
           fact.set (R);
           fact.delete_sym (j-1);
 
@@ -1124,7 +1127,7 @@ triangular, return the Cholesky@tie{}factorization of @w{A(p,p)}, where
           // complex case
           ComplexMatrix R = argr.complex_matrix_value ();
 
-          octave::math::chol<ComplexMatrix> fact;
+          math::chol<ComplexMatrix> fact;
           fact.set (R);
           fact.delete_sym (j-1);
 
@@ -1221,7 +1224,7 @@ triangular, return the Cholesky@tie{}factorization of
           // real case
           FloatMatrix R = argr.float_matrix_value ();
 
-          octave::math::chol<FloatMatrix> fact;
+          math::chol<FloatMatrix> fact;
           fact.set (R);
           fact.shift_sym (i-1, j-1);
 
@@ -1232,7 +1235,7 @@ triangular, return the Cholesky@tie{}factorization of
           // complex case
           FloatComplexMatrix R = argr.float_complex_matrix_value ();
 
-          octave::math::chol<FloatComplexMatrix> fact;
+          math::chol<FloatComplexMatrix> fact;
           fact.set (R);
           fact.shift_sym (i-1, j-1);
 
@@ -1246,7 +1249,7 @@ triangular, return the Cholesky@tie{}factorization of
           // real case
           Matrix R = argr.matrix_value ();
 
-          octave::math::chol<Matrix> fact;
+          math::chol<Matrix> fact;
           fact.set (R);
           fact.shift_sym (i-1, j-1);
 
@@ -1257,7 +1260,7 @@ triangular, return the Cholesky@tie{}factorization of
           // complex case
           ComplexMatrix R = argr.complex_matrix_value ();
 
-          octave::math::chol<ComplexMatrix> fact;
+          math::chol<ComplexMatrix> fact;
           fact.set (R);
           fact.shift_sym (i-1, j-1);
 
@@ -1329,3 +1332,5 @@ triangular, return the Cholesky@tie{}factorization of
 %! assert (norm (triu (R1)-R1, Inf), 0);
 %! assert (norm (R1'*R1 - single (Ac(p,p)), Inf) < 1e1*eps ("single"));
 */
+
+OCTAVE_NAMESPACE_END
