@@ -1,24 +1,27 @@
-/*
-
-Copyright (C) 2009-2018 VZLU Prague
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2009-2022 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -26,10 +29,14 @@ along with Octave; see the file COPYING.  If not, see
 
 #include "lo-blas-proto.h"
 #include "mx-base.h"
-#include "error.h"
+
+#include "builtin-defun-decls.h"
 #include "defun.h"
+#include "error.h"
 #include "parse.h"
 
+OCTAVE_NAMESPACE_BEGIN
+
 static void
 get_red_dims (const dim_vector& x, const dim_vector& y, int dim,
               dim_vector& z, F77_INT& m, F77_INT& n, F77_INT& k)
@@ -54,14 +61,14 @@ get_red_dims (const dim_vector& x, const dim_vector& y, int dim,
         }
       else
         {
-          tmp_k = x(i);
           z(i) = 1;
+          tmp_k = x(i);
         }
     }
 
-  m = octave::to_f77_int (tmp_m);
-  n = octave::to_f77_int (tmp_n);
-  k = octave::to_f77_int (tmp_k);
+  m = to_f77_int (tmp_m);
+  n = to_f77_int (tmp_n);
+  k = to_f77_int (tmp_k);
 }
 
 DEFUN (dot, args, ,
@@ -75,11 +82,12 @@ first non-singleton dimension.
 If the optional argument @var{dim} is given, calculate the dot products
 along this dimension.
 
-This is equivalent to
-@code{sum (conj (@var{X}) .* @var{Y}, @var{dim})},
-but avoids forming a temporary array and is faster.  When @var{X} and
-@var{Y} are column vectors, the result is equivalent to
-@code{@var{X}' * @var{Y}}.
+Implementation Note: This is equivalent to
+@code{sum (conj (@var{X}) .* @var{Y}, @var{dim})}, but avoids forming a
+temporary array and is faster.  When @var{X} and @var{Y} are column vectors,
+the result is equivalent to @code{@var{X}' * @var{Y}}.  Although, @code{dot}
+is defined for integer arrays, the output may differ from the expected result
+due to the limited range of integer objects.
 @seealso{cross, divergence}
 @end deftypefn */)
 {
@@ -177,11 +185,16 @@ but avoids forming a temporary array and is faster.  When @var{X} and
   else
     {
       // Non-optimized evaluation.
+      // FIXME: This may *not* do what the user expects.
+      // It might be more useful to issue a warning, or even an error, instead
+      // of calculating possibly garbage results.
+      // Think of the dot product of two int8 vectors where the multiplications
+      // exceed intmax.
       octave_value_list tmp;
       tmp(1) = dim + 1;
-      tmp(0) = do_binary_op (octave_value::op_el_mul, argx, argy);
+      tmp(0) = binary_op (octave_value::op_el_mul, argx, argy);
 
-      tmp = octave::feval ("sum", tmp, 1);
+      tmp = Fsum (tmp, 1);
       if (! tmp.empty ())
         retval = tmp(0);
     }
@@ -204,17 +217,23 @@ but avoids forming a temporary array and is faster.  When @var{X} and
 %! assert (dot (single (x), single (x)), single ([4, 20]));
 
 %!test
-%! x = int8 ([1 2]);
-%! y = int8 ([2 3]);
+%! x = int8 ([1, 2]);
+%! y = int8 ([2, 3]);
 %! assert (dot (x, y), 8);
 
 %!test
-%! x = int8 ([1 2; 3 4]);
-%! y = int8 ([5 6; 7 8]);
+%! x = int8 ([1, 2; 3, 4]);
+%! y = int8 ([5, 6; 7, 8]);
 %! assert (dot (x, y), [26 44]);
 %! assert (dot (x, y, 2), [17; 53]);
 %! assert (dot (x, y, 3), [5 12; 21 32]);
 
+## This is, perhaps, surprising.  Integer maximums and saturation mechanics
+## prevent accurate value from being calculated.
+%!test
+%! x = int8 ([127]);
+%! assert (dot (x, x), 127);
+
 ## Test input validation
 %!error dot ()
 %!error dot (1)
@@ -228,7 +247,7 @@ but avoids forming a temporary array and is faster.  When @var{X} and
 */
 
 template <typename T>
-void
+static void
 blkmm_internal (const T& x, const T& y, T& z,
                 F77_INT m, F77_INT n, F77_INT k, F77_INT np);
 
@@ -283,13 +302,13 @@ get_blkmm_dims (const dim_vector& dimx, const dim_vector& dimy,
 {
   int nd = dimx.ndims ();
 
-  m = octave::to_f77_int (dimx(0));
-  k = octave::to_f77_int (dimx(1));
-  n = octave::to_f77_int (dimy(1));
+  m = to_f77_int (dimx(0));
+  k = to_f77_int (dimx(1));
+  n = to_f77_int (dimy(1));
 
   octave_idx_type tmp_np = 1;
 
-  bool match = dimy(0) == k && nd == dimy.ndims ();
+  bool match = ((dimy(0) == k) && (nd == dimy.ndims ()));
 
   dimz = dim_vector::alloc (nd);
 
@@ -297,12 +316,12 @@ get_blkmm_dims (const dim_vector& dimx, const dim_vector& dimy,
   dimz(1) = n;
   for (int i = 2; match && i < nd; i++)
     {
-      match = match && dimx(i) == dimy(i);
+      match = (dimx(i) == dimy(i));
       dimz(i) = dimx(i);
       tmp_np *= dimz(i);
     }
 
-  np = octave::to_f77_int (tmp_np);
+  np = to_f77_int (tmp_np);
 
   if (! match)
     error ("blkmm: A and B dimensions don't match: (%s) and (%s)",
@@ -413,3 +432,5 @@ endfor
 %!error <A and B must be numeric> blkmm ([3,4], {1,2})
 %!error <A and B dimensions don't match> blkmm (ones (2,2), ones (3,3))
 */
+
+OCTAVE_NAMESPACE_END
