@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2016-2021 The Octave Project Developers
+// Copyright (C) 2016-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -31,6 +31,8 @@
 #include "errwarn.h"
 #include "oct-hdf5.h"
 
+OCTAVE_NAMESPACE_BEGIN
+
 bool
 check_hdf5_types (bool warn)
 {
@@ -67,3 +69,5 @@ check_hdf5_types (bool warn)
 
   return ok;
 }
+
+OCTAVE_NAMESPACE_END
