@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2008-2021 The Octave Project Developers
+// Copyright (C) 2008-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -33,6 +33,8 @@
 #include "ovl.h"
 #include "utils.h"
 
+OCTAVE_NAMESPACE_BEGIN
+
 DEFUN (rcond, args, ,
        doc: /* -*- texinfo -*-
 @deftypefn {} {@var{c} =} rcond (@var{A})
@@ -106,3 +108,5 @@ instead.
 %!assert (rcond (sx*i) < eps ('single'))
 
 */
+
+OCTAVE_NAMESPACE_END
