@@ -1,26 +1,27 @@
-/*
-
-Copyright (C) 1996-2019 John W. Eaton
-Copyright (C) 2008-2009 Jaroslav Hajek
-Copyright (C) 2009-2010 VZLU Prague, a.s.
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1996-2022 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if ! defined (octave_mx_op_defs_h)
 #define octave_mx_op_defs_h 1
@@ -606,7 +607,7 @@ along with Octave; see the file COPYING.  If not, see
     else                                                                \
       {                                                                 \
         result = M (nr, nc);                                            \
-        result.assign (p.col_perm_vec (), idx_vector::colon, x);        \
+        result.assign (p.col_perm_vec (), octave::idx_vector::colon, x);        \
       }                                                                 \
                                                                         \
     return result;                                                      \
@@ -621,7 +622,7 @@ along with Octave; see the file COPYING.  If not, see
     if (p.rows () != nc)                                                \
       octave::err_nonconformant ("operator *", nr, nc, p.rows (), p.columns ()); \
                                                                         \
-    result = x.index (idx_vector::colon, p.col_perm_vec ());            \
+    result = x.index (octave::idx_vector::colon, p.col_perm_vec ());            \
                                                                         \
     return result;                                                      \
   }
