@@ -1,30 +1,32 @@
 // This file is not compiled to a separate object file.
 // It is included in pathsearch.cc.
 
-/* Look up a filename in a path.
+//////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1991-2022 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
-Copyright (C) 2003-2018 John W. Eaton
-Copyright (C) 1993, 94, 95, 96, 97, 98 Karl Berry.
-Copyright (C) 1993, 94, 95, 96, 97 Karl Berry & O. Weber.
-Copyright (C) 1992, 93, 94, 95, 96, 97 Free Software Foundation, Inc.
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+//  Look up a filename in a path.
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -44,7 +46,7 @@ along with Octave; see the file COPYING.  If not, see
 #include "file-stat.h"
 #include "kpse.h"
 #include "oct-env.h"
-#include "oct-passwd.h"
+#include "oct-password.h"
 #include "oct-time.h"
 #include "pathsearch.h"
 #include "unistd-wrappers.h"
@@ -52,6 +54,8 @@ along with Octave; see the file COPYING.  If not, see
 #if defined (OCTAVE_USE_WINDOWS_API)
 #  define WIN32_LEAN_AND_MEAN 1
 #  include <windows.h>
+
+#  include "lo-sysdep.h"
 #endif
 
 // Define the characters which separate components of filenames and
@@ -87,40 +91,36 @@ along with Octave; see the file COPYING.  If not, see
 
 unsigned int kpse_debug = 0;
 
-static std::string kpse_var_expand (const std::string& src);
-
-static std::string kpse_expand (const std::string& s);
-
 void
 kpse_path_iterator::set_end (void)
 {
-  e = b + 1;
+  m_e = m_b + 1;
 
-  if (e == len)
+  if (m_e == m_len)
     ; // OK, we have found the last element.
-  else if (e > len)
-    b = e = std::string::npos;
+  else if (m_e > m_len)
+    m_b = m_e = std::string::npos;
   else
     {
       // Find the next colon not enclosed by braces (or the end of the
       // path).
 
-      while (e < len && ! octave::directory_path::is_path_sep (path[e]))
-        e++;
+      while (m_e < m_len && ! octave::directory_path::is_path_sep (m_path[m_e]))
+        m_e++;
     }
 }
 
 void
 kpse_path_iterator::next (void)
 {
-  b = e + 1;
+  m_b = m_e + 1;
 
   // Skip any consecutive colons.
-  while (b < len && octave::directory_path::is_path_sep (path[b]))
-    b++;
+  while (m_b < m_len && octave::directory_path::is_path_sep (m_path[m_b]))
+    m_b++;
 
-  if (b >= len)
-    b = e = std::string::npos;
+  if (m_b >= m_len)
+    m_b = m_e = std::string::npos;
   else
     set_end ();
 }
@@ -136,9 +136,9 @@ kpse_truncate_filename (const std::string& name)
 
   std::string ret = name;
 
-  size_t len = name.length ();
+  std::size_t m_len = name.length ();
 
-  for (size_t i = 0; i < len; i++)
+  for (std::size_t i = 0; i < m_len; i++)
     {
       if (IS_DIR_SEP (name[i]) || IS_DEVICE_SEP (name[i]))
         {
@@ -166,18 +166,19 @@ kpse_truncate_filename (const std::string& name)
    regular file, as it is potentially useful to read fifo's or some
    kinds of devices.  */
 
+static inline bool
+READABLE (const std::string& fn)
+{
 #if defined (OCTAVE_USE_WINDOWS_API)
-static inline bool
-READABLE (const std::string& fn)
-{
-  const char *t = fn.c_str ();
-  return (GetFileAttributes (t) != 0xFFFFFFFF
-          && ! (GetFileAttributes (t) & FILE_ATTRIBUTE_DIRECTORY));
-}
+
+  std::wstring w_fn = octave::sys::u8_to_wstring (fn);
+
+  DWORD f_attr = GetFileAttributesW (w_fn.c_str ());
+
+  return (f_attr != 0xFFFFFFFF && ! (f_attr & FILE_ATTRIBUTE_DIRECTORY));
+
 #else
-static inline bool
-READABLE (const std::string& fn)
-{
+
   bool retval = false;
 
   const char *t = fn.c_str ();
@@ -190,8 +191,9 @@ READABLE (const std::string& fn)
     }
 
   return retval;
-}
+
 #endif
+}
 
 /* POSIX invented the brain-damage of not necessarily truncating
    filename components; the system's behavior is defined by the value of
@@ -344,6 +346,8 @@ path_search (const std::string& path, const std::string& name, bool all)
               elt = elt.substr (1);
             }
         }
+#if (! defined (OCTAVE_HAVE_WINDOWS_FILESYSTEM) \
+     && ! defined (DOUBLE_SLASH_IS_DISTINCT_ROOT))
       else
         {
           /* We never want to search the whole disk.  */
@@ -351,6 +355,7 @@ path_search (const std::string& path, const std::string& name, bool all)
                  && IS_DIR_SEP (elt[0]) && IS_DIR_SEP (elt[1]))
             elt = elt.substr (1);
         }
+#endif
 
       /* Our caller (search), also tests first_search, and does
          the resetting.  */
@@ -383,6 +388,101 @@ path_search (const std::string& path, const std::string& name, bool all)
   return ret_list;
 }
 
+/* If NAME has a leading ~ or ~user, Unix-style, expand it to the user's
+   home directory, and return a new malloced string.  If no ~, or no
+   <pwd.h>, just return NAME.  */
+
+static std::string
+kpse_tilde_expand (const std::string& name)
+{
+  std::string expansion;
+
+  /* If no leading tilde, do nothing.  */
+  if (name.empty () || name[0] != '~')
+    {
+      expansion = name;
+
+      /* If a bare tilde, return the home directory or '.'.  (Very
+         unlikely that the directory name will do anyone any good, but
+         ...  */
+    }
+  else if (name.length () == 1)
+    {
+      expansion = octave::sys::env::get_home_directory ();
+
+      if (expansion.empty ())
+        expansion = ".";
+
+      /* If '~/', remove any trailing / or replace leading // in $HOME.
+         Should really check for doubled intermediate slashes, too.  */
+    }
+  else if (IS_DIR_SEP (name[1]))
+    {
+      unsigned c = 1;
+      std::string home = octave::sys::env::get_home_directory ();
+
+      if (home.empty ())
+        home = ".";
+
+      std::size_t home_len = home.length ();
+
+#if (! defined (OCTAVE_HAVE_WINDOWS_FILESYSTEM) \
+     && ! defined (DOUBLE_SLASH_IS_DISTINCT_ROOT))
+      /* handle leading // */
+      if (home_len > 1 && IS_DIR_SEP (home[0]) && IS_DIR_SEP (home[1]))
+        home = home.substr (1);
+#endif
+
+      /* omit / after ~ */
+      if (IS_DIR_SEP (home[home_len - 1]))
+        c++;
+
+      expansion = home + name.substr (c);
+
+      /* If '~user' or '~user/', look up user in the passwd database (but
+         OS/2 doesn't have this concept.  */
+    }
+  else
+#if defined (HAVE_PWD_H)
+    {
+      unsigned c = 2;
+
+      /* find user name */
+      while (name.length () > c && ! IS_DIR_SEP (name[c]))
+        c++;
+
+      std::string user = name.substr (1, c-1);
+
+      /* We only need the cast here for (deficient) systems
+         which do not declare 'getpwnam' in <pwd.h>.  */
+      octave::sys::password p = octave::sys::password::getpwnam (user);
+
+      /* If no such user, just use '.'.  */
+      std::string home = (p ? p.dir () : ".");
+
+      if (home.empty ())
+        home = ".";
+
+#  if (! defined (OCTAVE_HAVE_WINDOWS_FILESYSTEM) \
+       && ! defined (DOUBLE_SLASH_IS_DISTINCT_ROOT))
+      /* handle leading // */
+      if (home.length () > 1 && IS_DIR_SEP (home[0]) && IS_DIR_SEP (home[1]))
+        home = home.substr (1);
+#  endif
+
+      /* If HOME ends in /, omit the / after ~user. */
+      if (name.length () > c && IS_DIR_SEP (home.back ()))
+        c++;
+
+      expansion = (name.length () > c ? home : home + name.substr (c));
+    }
+#else /* not HAVE_PWD_H */
+  expansion = name;
+#endif /* not HAVE_PWD_H */
+
+  return expansion;
+}
+
 /* Search PATH for ORIGINAL_NAME.  If ALL is false, or ORIGINAL_NAME is
    absolute_p, check ORIGINAL_NAME itself.  Otherwise, look at each
    element of PATH for the first readable ORIGINAL_NAME.
@@ -398,8 +498,8 @@ search (const std::string& path, const std::string& original_name,
   std::list<std::string> ret_list;
   bool absolute_p;
 
-  /* Make a leading ~ count as an absolute filename, and expand $FOO's.  */
-  std::string name = kpse_expand (original_name);
+  /* Make a leading ~ count as an absolute filename.  */
+  std::string name = kpse_tilde_expand (original_name);
 
   /* If the first name is absolute or explicitly relative, no need to
      consider PATH at all.  */
@@ -440,7 +540,7 @@ search (const std::string& path, const std::string& original_name,
 
 /* Search PATH for the first NAME.  */
 
-/* Call 'kpse_expand' on NAME.  If the result is an absolute or
+/* Perform tilde expansion on NAME.  If the result is an absolute or
    explicitly relative filename, check whether it is a readable
    (regular) file.
 
@@ -499,6 +599,8 @@ path_find_first_of (const std::string& path,
               elt = elt.substr (1);
             }
         }
+#if (! defined (OCTAVE_HAVE_WINDOWS_FILESYSTEM) \
+     && ! defined (DOUBLE_SLASH_IS_DISTINCT_ROOT))
       else
         {
           /* We never want to search the whole disk.  */
@@ -506,6 +608,7 @@ path_find_first_of (const std::string& path,
                  && IS_DIR_SEP (elt[0]) && IS_DIR_SEP (elt[1]))
             elt = elt.substr (1);
         }
+#endif
 
       /* We have to search one directory at a time.  */
       dir = kpse_element_dir (elt);
@@ -647,235 +750,20 @@ kpse_all_path_find_first_of (const std::string& path,
   return find_first_of (path, names, true);
 }
 
-/* If NAME has a leading ~ or ~user, Unix-style, expand it to the user's
-   home directory, and return a new malloced string.  If no ~, or no
-   <pwd.h>, just return NAME.  */
-
-static std::string
-kpse_tilde_expand (const std::string& name)
-{
-  std::string expansion;
-
-  /* If no leading tilde, do nothing.  */
-  if (name.empty () || name[0] != '~')
-    {
-      expansion = name;
-
-      /* If a bare tilde, return the home directory or '.'.  (Very
-         unlikely that the directory name will do anyone any good, but
-         ...  */
-    }
-  else if (name.length () == 1)
-    {
-      expansion = octave::sys::env::get_home_directory ();
-
-      if (expansion.empty ())
-        expansion = ".";
-
-      /* If '~/', remove any trailing / or replace leading // in $HOME.
-         Should really check for doubled intermediate slashes, too.  */
-    }
-  else if (IS_DIR_SEP (name[1]))
-    {
-      unsigned c = 1;
-      std::string home = octave::sys::env::get_home_directory ();
-
-      if (home.empty ())
-        home = ".";
-
-      size_t home_len = home.length ();
-
-      /* handle leading // */
-      if (home_len > 1 && IS_DIR_SEP (home[0]) && IS_DIR_SEP (home[1]))
-        home = home.substr (1);
-
-      /* omit / after ~ */
-      if (IS_DIR_SEP (home[home_len - 1]))
-        c++;
-
-      expansion = home + name.substr (c);
-
-      /* If '~user' or '~user/', look up user in the passwd database (but
-         OS/2 doesn't have this concept.  */
-    }
-  else
-#if defined (HAVE_PWD_H)
-    {
-      unsigned c = 2;
-
-      /* find user name */
-      while (name.length () > c && ! IS_DIR_SEP (name[c]))
-        c++;
-
-      std::string user = name.substr (1, c-1);
-
-      /* We only need the cast here for (deficient) systems
-         which do not declare 'getpwnam' in <pwd.h>.  */
-      octave::sys::password p = octave::sys::password::getpwnam (user);
-
-      /* If no such user, just use '.'.  */
-      std::string home = (p ? p.dir () : ".");
-
-      if (home.empty ())
-        home = ".";
-
-      /* handle leading // */
-      if (home.length () > 1 && IS_DIR_SEP (home[0]) && IS_DIR_SEP (home[1]))
-        home = home.substr (1);
-
-      /* If HOME ends in /, omit the / after ~user. */
-      if (name.length () > c && IS_DIR_SEP (home.back ()))
-        c++;
-
-      expansion = (name.length () > c ? home : home + name.substr (c));
-    }
-#else /* not HAVE_PWD_H */
-  expansion = name;
-#endif /* not HAVE_PWD_H */
-
-  return expansion;
-}
-
-/* Do variable expansion first so ~${USER} works.  (Besides, it's what the
-   shells do.)  */
-
-/* Call kpse_var_expand and kpse_tilde_expand (in that order).  Result
-   is always in fresh memory, even if no expansions were done.  */
-
-static std::string
-kpse_expand (const std::string& s)
-{
-  std::string var_expansion = kpse_var_expand (s);
-  return kpse_tilde_expand (var_expansion);
-}
-
-/* Forward declarations of functions from the original expand.c  */
-static std::list<std::string> brace_expand (const std::string&);
-
-/* If $KPSE_DOT is defined in the environment, prepend it to any relative
-   path components. */
-
-static std::string
-kpse_expand_kpse_dot (const std::string& path)
-{
-  std::string ret;
-  std::string kpse_dot = octave::sys::env::getenv ("KPSE_DOT");
-
-  if (kpse_dot.empty ())
-    return path;
-
-  for (kpse_path_iterator pi (path); pi != std::string::npos; pi++)
-    {
-      std::string elt = *pi;
-
-      /* Single "." get special treatment, as does "./" or its equivalent.  */
-
-      size_t elt_len = elt.length ();
-
-      if (kpse_absolute_p (elt, false))
-        ret += elt + ENV_SEP_STRING;
-      else if (elt_len == 1 && elt[0] == '.')
-        ret += kpse_dot + ENV_SEP_STRING;
-      else if (elt_len > 1 && elt[0] == '.' && IS_DIR_SEP (elt[1]))
-        ret += kpse_dot + elt.substr (1) + ENV_SEP_STRING;
-      else
-        ret += kpse_dot + DIR_SEP_STRING + elt + ENV_SEP_STRING;
-    }
-
-  if (! ret.empty ())
-    ret.pop_back ();
-
-  return ret;
-}
-
-/* Do brace expansion on ELT; then do variable and ~ expansion on each
-   element of the result; then do brace expansion again, in case a
-   variable definition contained braces (e.g., $TEXMF).  Return a
-   string comprising all of the results separated by ENV_SEP_STRING.  */
-
-static std::string
-kpse_brace_expand_element (const std::string& elt)
-{
-  std::string ret;
-
-  std::list<std::string> expansions = brace_expand (elt);
-
-  for (const auto& expanded_elt : expansions)
-    {
-      /* Do $ and ~ expansion on each element.  */
-      std::string x = kpse_expand (expanded_elt);
-
-      if (x != elt)
-        {
-          /* If we did any expansions, do brace expansion again.  Since
-             recursive variable definitions are not allowed, this recursion
-             must terminate.  (In practice, it's unlikely there will ever be
-             more than one level of recursion.)  */
-          x = kpse_brace_expand_element (x);
-        }
-
-      ret += x + ENV_SEP_STRING;
-    }
-
-  ret.pop_back ();
-
-  return ret;
-}
-
-/* Do brace expansion and call 'kpse_expand' on each element of the
-   result; return the final expansion (always in fresh memory, even if
-   no expansions were done).  */
-
-static std::string
-kpse_brace_expand (const std::string& path)
-{
-  /* Must do variable expansion first because if we have
-       foo = .:~
-       TEXINPUTS = $foo
-     we want to end up with TEXINPUTS = .:/home/karl.
-     Since kpse_path_element is not reentrant, we must get all
-     the path elements before we start the loop.  */
-  std::string tmp = kpse_var_expand (path);
-
-  std::string ret;
-
-  for (kpse_path_iterator pi (tmp); pi != std::string::npos; pi++)
-    {
-      std::string elt = *pi;
-
-      /* Do brace expansion first, so tilde expansion happens in {~ka,~kb}.  */
-      std::string expansion = kpse_brace_expand_element (elt);
-      ret += expansion + ENV_SEP_STRING;
-    }
-
-  if (! ret.empty ())
-    ret.pop_back ();
-
-  return kpse_expand_kpse_dot (ret);
-}
-
-/* Expand all special constructs in a path, and include only the actually
-   existing directories in the result. */
-
-/* Do brace expansion and call 'kpse_expand' on each argument of the
-   result.  The final expansion (always in fresh memory) is a path of
-   all the existing directories that match the pattern. */
+/* Perform tilde expansion on each element of the path, and include
+   canonical directory names for only the the actually existing
+   directories in the result. */
 
 std::string
 kpse_path_expand (const std::string& path)
 {
   std::string ret;
-  unsigned len;
-
-  len = 0;
-
-  /* Expand variables and braces first.  */
-  std::string tmp = kpse_brace_expand (path);
+  unsigned len = 0;
 
   /* Now expand each of the path elements, printing the results */
-  for (kpse_path_iterator pi (tmp); pi != std::string::npos; pi++)
+  for (kpse_path_iterator pi (path); pi != std::string::npos; pi++)
     {
-      std::string elt = *pi;
+      std::string elt = kpse_tilde_expand (*pi);
 
       std::string dir;
 
@@ -890,6 +778,8 @@ kpse_path_expand (const std::string& path)
               elt = elt.substr (1);
             }
         }
+#if (! defined (OCTAVE_HAVE_WINDOWS_FILESYSTEM) \
+     && ! defined (DOUBLE_SLASH_IS_DISTINCT_ROOT))
       else
         {
           /* We never want to search the whole disk.  */
@@ -897,12 +787,13 @@ kpse_path_expand (const std::string& path)
                  && IS_DIR_SEP (elt[0]) && IS_DIR_SEP (elt[1]))
             elt = elt.substr (1);
         }
+#endif
 
       /* Search the disk for all dirs in the component specified.
          Be faster to check the database, but this is more reliable.  */
       dir = kpse_element_dir (elt);
 
-      size_t dirlen = dir.length ();
+      std::size_t dirlen = dir.length ();
 
       if (dirlen > 0)
         {
@@ -1024,8 +915,8 @@ expand_amble (const std::string& text)
 {
   std::list<std::string> result;
 
-  size_t text_len = text.length ();
-  size_t start;
+  std::size_t text_len = text.length ();
+  std::size_t start;
   int i, c;
 
   for (start = 0, i = 0, c = 1; c && start < text_len; start = ++i)
@@ -1062,9 +953,9 @@ brace_gobbler (const std::string& text, int& indx, int satisfy)
   int quoted = 0;
   int pass_next = 0;
 
-  size_t text_len = text.length ();
+  std::size_t text_len = text.length ();
 
-  size_t i = indx;
+  std::size_t i = indx;
 
   for (; i < text_len; i++)
     {
@@ -1120,67 +1011,10 @@ brace_gobbler (const std::string& text, int& indx, int satisfy)
     }
 
   indx = i;
+  c = (c == satisfy) ? c : 0;
   return c;
 }
 
-/* Expand extra colons.  */
-
-/* Check for leading colon first, then trailing, then doubled, since
-   that is fastest.  Usually it will be leading or trailing.  */
-
-/* Replace a leading or trailing or doubled : in PATH with DFLT.  If
-   no extra colons, return PATH.  Only one extra colon is replaced.
-   DFLT may not be NULL.  */
-
-std::string
-kpse_expand_default (const std::string& path, const std::string& fallback)
-{
-  std::string expansion;
-
-  size_t path_len = path.length ();
-
-  if (path_len == 0)
-    expansion = fallback;
-
-  /* Solitary or leading :?  */
-  else if (IS_ENV_SEP (path[0]))
-    {
-      expansion = (path_len == 1 ? fallback : fallback + path);
-    }
-
-  /* Sorry about the assignment in the middle of the expression, but
-     conventions were made to be flouted and all that.  I don't see the
-     point of calling strlen twice or complicating the logic just to
-     avoid the assignment (especially now that I've pointed it out at
-     such great length).  */
-  else if (IS_ENV_SEP (path[path_len-1]))
-    expansion = path + fallback;
-
-  /* OK, not leading or trailing.  Check for doubled.  */
-  else
-    {
-      /* What we'll return if we find none.  */
-      expansion = path;
-
-      for (size_t i = 0; i < path_len; i++)
-        {
-          if (i + 1 < path_len
-              && IS_ENV_SEP (path[i]) && IS_ENV_SEP (path[i+1]))
-            {
-              /* We have a doubled colon.  */
-
-              /* Copy stuff up to and including the first colon.  */
-              /* Copy in FALLBACK, and then the rest of PATH.  */
-              expansion = path.substr (0, i+1) + fallback + path.substr (i+1);
-
-              break;
-            }
-        }
-    }
-
-  return expansion;
-}
-
 /* Return true if FN is a directory or a symlink to a directory,
    false if not. */
 
@@ -1220,151 +1054,3 @@ kpse_element_dir (const std::string& elt)
 
   return ret;
 }
-
-/* Variable expansion.  */
-
-/* We have to keep track of variables being expanded, otherwise
-   constructs like TEXINPUTS = $TEXINPUTS result in an infinite loop.
-   (Or indirectly recursive variables, etc.)  Our simple solution is to
-   add to a list each time an expansion is started, and check the list
-   before expanding.  */
-
-static std::map <std::string, bool> expansions;
-
-static void
-expanding (const std::string& var, bool xp)
-{
-  expansions[var] = xp;
-}
-
-/* Return whether VAR is currently being expanding.  */
-
-static bool
-expanding_p (const std::string& var)
-{
-  return (expansions.find (var) != expansions.end ()) ? expansions[var] : false;
-}
-
-/* Append the result of value of 'var' to EXPANSION, where 'var' begins
-   at START and ends at END.  If 'var' is not set, do not complain.
-   This is a subroutine for the more complicated expansion function.  */
-
-static void
-expand (std::string& expansion, const std::string& var)
-{
-  if (expanding_p (var))
-    {
-      (*current_liboctave_warning_with_id_handler)
-        ("Octave:pathsearch-syntax",
-         "pathsearch: variable '%s' references itself (eventually)",
-         var.c_str ());
-    }
-  else
-    {
-      /* Check for an environment variable.  */
-      std::string value = octave::sys::env::getenv (var);
-
-      if (! value.empty ())
-        {
-          expanding (var, true);
-          std::string tmp = kpse_var_expand (value);
-          expanding (var, false);
-          expansion += tmp;
-        }
-    }
-}
-
-/* Can't think of when it would be useful to change these (and the
-   diagnostic messages assume them), but ... */
-
-/* starts all variable references */
-#if ! defined (IS_VAR_START)
-#  define IS_VAR_START(c) ((c) == '$')
-#endif
-
-/* variable name constituent */
-#if ! defined (IS_VAR_CHAR)
-#  define IS_VAR_CHAR(c) (isalnum (c) || (c) == '_')
-#endif
-
-/* start delimited variable name (after $) */
-#if ! defined (IS_VAR_BEGIN_DELIMITER)
-#  define IS_VAR_BEGIN_DELIMITER(c) ((c) == '{')
-#endif
-
-#if ! defined (IS_VAR_END_DELIMITER)
-#  define IS_VAR_END_DELIMITER(c) ((c) == '}')
-#endif
-
-/* Maybe we should support some or all of the various shell ${...}
-   constructs, especially ${var-value}.  */
-
-static std::string
-kpse_var_expand (const std::string& src)
-{
-  std::string expansion;
-
-  size_t src_len = src.length ();
-
-  /* Copy everything but variable constructs.  */
-  for (size_t i = 0; i < src_len; i++)
-    {
-      if (IS_VAR_START (src[i]))
-        {
-          i++;
-
-          /* Three cases: '$VAR', '${VAR}', '$<anything-else>'.  */
-          if (IS_VAR_CHAR (src[i]))
-            {
-              /* $V: collect name constituents, then expand.  */
-              size_t var_end = i;
-
-              do
-                {
-                  var_end++;
-                }
-              while (IS_VAR_CHAR (src[var_end]));
-
-              var_end--; /* had to go one past */
-              expand (expansion, src.substr (i, var_end - i + 1));
-              i = var_end;
-
-            }
-          else if (IS_VAR_BEGIN_DELIMITER (src[i]))
-            {
-              /* ${: scan ahead for matching delimiter, then expand.  */
-              size_t var_end = ++i;
-
-              while (var_end < src_len && ! IS_VAR_END_DELIMITER (src[var_end]))
-                var_end++;
-
-              if (var_end == src_len)
-                {
-                  (*current_liboctave_warning_with_id_handler)
-                    ("Octave:pathsearch-syntax",
-                     "%s: No matching } for ${", src.c_str ());
-                  i = var_end - 1; /* will incr to eos at top of loop */
-                }
-              else
-                {
-                  expand (expansion, src.substr (i, var_end - i));
-                  i = var_end; /* will incr past } at top of loop*/
-                }
-            }
-          else
-            {
-              /* $<something-else>: error.  */
-              (*current_liboctave_warning_with_id_handler)
-                ("Octave:pathsearch-syntax",
-                 "%s: Unrecognized variable construct '$%c'",
-                 src.c_str (), src[i]);
-
-              /* Just ignore those chars and keep going.  */
-            }
-        }
-      else
-        expansion += src[i];
-    }
-
-  return expansion;
-}
