@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2016-2021 The Octave Project Developers
+// Copyright (C) 2016-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -30,7 +30,8 @@
 extern "C" {
 #endif
 
-extern const char * octave_set_program_name_wrapper (const char *pname);
+extern OCTAVE_API const char *
+octave_set_program_name_wrapper (const char *pname);
 
 #if defined __cplusplus
 }
