@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2013-2020 The Octave Project Developers
+## Copyright (C) 2013-2022 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -30,7 +30,7 @@
 
 function resume (recorder)
 
-  if (nargin != 1)
+  if (nargin < 1)
     print_usage ();
   endif
 
