@@ -1,4 +1,9 @@
-## Copyright (C) 2000-2018 Teemu Ikonen
+########################################################################
+##
+## Copyright (C) 2000-2022 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} errorbar (@var{y}, @var{ey})
@@ -163,10 +170,6 @@
 ## @seealso{semilogxerr, semilogyerr, loglogerr, plot}
 ## @end deftypefn
 
-## Created: 18.7.2000
-## Author: Teemu Ikonen <tpikonen@pcu.helsinki.fi>
-## Keywords: errorbar, plotting
-
 function h = errorbar (varargin)
 
   [hax, varargin] = __plt_get_axis_arg__ ("errorbar", varargin{:});
@@ -244,7 +247,7 @@ endfunction
 ## Invisible figure used for tests
 %!shared hf, hax
 %! hf = figure ("visible", "off");
-%! hax = axes;
+%! hax = axes ();
 
 %!error errorbar ()
 %!error errorbar (1)
