@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 1995-2021 The Octave Project Developers
+## Copyright (C) 1995-2022 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -239,7 +239,7 @@ function h = subplot (varargin)
     set (cf, "units", "pixels");
 
     ## FIXME: At the moment we force gnuplot to use the aligned mode
-    ##        which will set "activepositionproperty" to "position".
+    ##        which will set "positionconstraint" to "innerposition".
     ##        This can yield to text overlap between labels and titles.
     ##        See bug #31610.
     if (strcmp (get (cf, "__graphics_toolkit__"), "gnuplot"))
@@ -329,7 +329,7 @@ function h = subplot (varargin)
         set (hsubplot, varargin{:});
       endif
     else
-      pval = [{"activepositionproperty", "position", ...
+      pval = [{"positionconstraint", "innerposition", ...
                "position", pos, "looseinset", li} varargin];
       if (! make_subplot)
         hsubplot = axes (pval{:});
@@ -374,7 +374,7 @@ function [pos, opos, li] = subplot_position (hf, nrows, ncols, idx)
 
   ## Row/Column inside the axes array
   row = ceil (idx / ncols);
-  col = idx .- (row - 1) * ncols;
+  col = idx - (row - 1) * ncols;
   row = [min(row) max(row)];
   col = [min(col) max(col)];
 
@@ -435,7 +435,7 @@ function [pos, opos, li] = subplot_position (hf, nrows, ncols, idx)
 
 endfunction
 
-function subplot_align (h, d, rmupdate = false)
+function subplot_align (h, ~, rmupdate = false)
   persistent updating = false;
 
   if (! updating)
@@ -446,7 +446,7 @@ function subplot_align (h, d, rmupdate = false)
         rmappdata (h, "__subplotposition__");
         rmappdata (h, "__subplotouterposition__");
       endif
-      return
+      return;
     endif
 
     unwind_protect
@@ -461,7 +461,7 @@ function subplot_align (h, d, rmupdate = false)
         do_align = ! cellfun (@isempty, pos);
         pos = cell2mat (pos(do_align));
       else
-        return
+        return;
       endif
       hsubplots = children(do_align);
 
@@ -476,7 +476,7 @@ function subplot_align (h, d, rmupdate = false)
         hsubplots(! do_align) = [];
         pos(! do_align,:) = [];
       else
-        return
+        return;
       endif
 
       ## Reset outerpositions to their default value
@@ -486,7 +486,7 @@ function subplot_align (h, d, rmupdate = false)
       endif
       for ii = 1:numel (hsubplots)
         set (hsubplots(ii), "outerposition", opos(ii,:), ...
-             "activepositionproperty", "position");
+             "positionconstraint", "innerposition");
       endfor
 
       ## Compare current positions to default and compute the new ones
