@@ -1,4 +1,9 @@
-## Copyright (C) 1995-2018 Andreas Weingessel
+########################################################################
+##
+## Copyright (C) 1995-2022 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} hanning (@var{m})
@@ -32,12 +39,9 @@
 ## @cite{Discrete-Time Signal Processing}.
 ## @end deftypefn
 
-## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
-## Description: Coefficients of the Hanning window
-
 function c = hanning (m, opt)
 
-  if (nargin < 1 || nargin > 2)
+  if (nargin < 1)
     print_usage ();
   endif
 
@@ -83,7 +87,7 @@ endfunction
 %! A = hanning (N, "periodic");
 %! assert (A(N/2 + 1), 1);
 
-%!error hanning ()
+%!error <Invalid call> hanning ()
 %!error hanning (0.5)
 %!error hanning (-1)
 %!error hanning (ones (1,4))
