@@ -1,4 +1,9 @@
-## Copyright (C) 1993-2019 Paul Kienzle
+########################################################################
+##
+## Copyright (C) 1993-2022 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -16,6 +21,8 @@
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
 ##
+########################################################################
+##
 ## Original version by Paul Kienzle distributed as free software in the
 ## public domain.
 
@@ -50,18 +57,17 @@
 ## @seealso{compan, hankel, toeplitz}
 ## @end deftypefn
 
-
 ## Reference [1] contains a list of Hadamard matrices up to n=256.
 ## See code for h28 in hadamard.m for an example of how to extend
 ## this function for additional p.
 ##
-## References:
+## Reference:
 ## [1] A Library of Hadamard Matrices, N. J. A. Sloane
 ##     http://www.research.att.com/~njas/hadamard/
 
 function h = hadamard (n)
 
-  if (nargin != 1)
+  if (nargin < 1)
     print_usage ();
   endif
 
@@ -128,6 +134,7 @@ function h = h20 ()
 endfunction
 
 function h = h28 ()
+
   ## Williamson matrix construction from
   ## http://www.research.att.com/~njas/hadamard/had.28.will.txt
   ## Normalized so that each row and column starts with +1
@@ -170,6 +177,6 @@ endfunction
 %!   assert (norm (h*h' - n*eye (n)), 0);
 %! endfor
 
-%!error hadamard ()
+%!error <Invalid call> hadamard ()
 %!error hadamard (1,2)
 %!error <N must be 2\^k\*p> hadamard (5)
