@@ -1,31 +1,38 @@
-## Copyright (C) 1993-2015 John W. Eaton
-## Copyright (C) 2009 VZLU Prague
+########################################################################
+##
+## Copyright (C) 1993-2022 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {} vander (@var{c})
-## @deftypefnx {Function File} {} vander (@var{c}, @var{n})
-## Return the Vandermonde matrix whose next to last column is @var{c}.
+## @deftypefn  {} {} vander (@var{c})
+## @deftypefnx {} {} vander (@var{c}, @var{n})
+## Return the @nospell{Vandermonde} matrix whose next to last column is
+## @var{c}.
 ##
 ## If @var{n} is specified, it determines the number of columns; otherwise,
 ## @var{n} is taken to be equal to the length of @var{c}.
 ##
-## A Vandermonde matrix has the form:
+## A @nospell{Vandermonde} matrix has the form:
 ## @tex
 ## $$
 ## \left[\matrix{c_1^{n-1}  & \cdots & c_1^2  & c_1    & 1      \cr
@@ -51,8 +58,6 @@
 ## @seealso{polyfit}
 ## @end deftypefn
 
-## Author: jwe
-
 function retval = vander (c, n)
 
   if (nargin == 1)
@@ -90,7 +95,5 @@ endfunction
 %!assert (vander (2, 3), [4, 2, 1])
 %!assert (vander ([2, 3], 3), [4, 2, 1; 9, 3, 1])
 
-%!error vander ()
-%!error vander (1, 2, 3)
+%!error <Invalid call> vander ()
 %!error <polynomial C must be a vector> vander ([1, 2; 3, 4])
-
