@@ -1,4 +1,9 @@
-## Copyright (C) 2010-2019 Ben Abbott
+########################################################################
+##
+## Copyright (C) 2010-2022 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} untabify (@var{t})
@@ -48,12 +55,9 @@
 ## @seealso{strjust, strsplit, deblank}
 ## @end deftypefn
 
-## Author: Ben Abbott <bpabbott@mac.com>
-## Created: 2010-10-15
-
 function s = untabify (t, tw = 8, deblank_arg = false)
 
-  if (nargin < 1 || nargin > 3)
+  if (nargin < 1)
     print_usage ();
   elseif (! (ischar (t) || iscellstr (t)))
     error ("untabify: T must be a string or cellstring");
@@ -118,6 +122,6 @@ endfunction
 %! s = char (randi ([97 97+25], 3, 3));
 %! assert (untabify (s), char (untabify (cellstr (s))));
 
-%!error untabify ()
-%!error untabify (1,2,3,4)
+## Test input validation
+%!error <Invalid call> untabify ()
 %!error <must be a string> untabify (1)
