@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2000-2021 The Octave Project Developers
+## Copyright (C) 2000-2022 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -26,7 +26,7 @@
 ## -*- texinfo -*-
 ## @deftypefn {} {t =} now ()
 ## Return the current local date/time as a serial day number
-## (see @code{datenum}).
+## (@pxref{XREFdatenum,,@code{datenum}}).
 ##
 ## The integral part, @code{floor (now)} corresponds to the number of days
 ## between today and Jan 1, 0000.
@@ -37,10 +37,6 @@
 
 function t = now ()
 
-  if (nargin != 0)
-    print_usage ();
-  endif
-
   t = datenum (clock ());
 
   ## The following doesn't work (e.g., one hour off on 2005-10-04):
@@ -59,5 +55,3 @@ endfunction
 %!assert (isnumeric (now ()))
 %!assert (now () > 0)
 %!assert (now () <= now ())
-
-%!error now (1)
