@@ -1,28 +1,28 @@
 #! /bin/sh
 
 ########################################################################
-#
-# Copyright (C) 2006-2020 The Octave Project Developers
-#
-# See the file COPYRIGHT.md in the top-level directory of this
-# distribution or <https://octave.org/copyright/>.
-#
-# This file is part of Octave.
-#
-# Octave is free software: you can redistribute it and/or modify it
-# under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# Octave is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Octave; see the file COPYING.  If not, see
-# <https://www.gnu.org/licenses/>.
-#
+##
+## Copyright (C) 2006-2022 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
+##
+## This file is part of Octave.
+##
+## Octave is free software: you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
+##
+## Octave is distributed in the hope that it will be useful, but
+## WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
+##
+## You should have received a copy of the GNU General Public License
+## along with Octave; see the file COPYING.  If not, see
+## <https://www.gnu.org/licenses/>.
+##
 ########################################################################
 
 # Some tests are commented out because they are known to be broken!
@@ -216,7 +216,7 @@ gen_specific_tests() {
 %!assert (nnz (sparse (1,1,0)), 0)
 %!assert (nnz (sparse (eye (3))*0), 0)
 %!assert (nnz (sparse (eye (3))-sparse (eye (3))), 0)
-%!assert (full (sparse (eye (3))/0), full (eye (3)/0));
+%!assert (full (sparse (eye (3))/0), full (eye (3)/0))
 
 EOF
 }
@@ -403,7 +403,7 @@ gen_matrixdiag_tests() {
 %!test
 %! [tb,tc] = spdiags (as);
 %! assert (spdiags (tb,tc,sparse (zeros (size (as)))), as);
-%! assert (spdiags (tb,tc,size (as,1),size (as,2)), as);
+%! assert (spdiags (tb,tc,rows (as),columns (as)), as);
 
 EOF
 }
@@ -576,8 +576,8 @@ gen_unaryop_tests() {
 %!assert (as',  sparse (af'))
 %!assert (-as, sparse (-af))
 %!assert (!as, sparse (!af))
-%!error [i,j] = size (af);as(i-1,j+1);
-%!error [i,j] = size (af);as(i+1,j-1);
+%!error [i,j] = size (af);as(i-1,j+1)
+%!error [i,j] = size (af);as(i+1,j-1)
 %!test
 %! [Is,Js,Vs] = find (as);
 %! [If,Jf,Vf] = find (af);
@@ -857,8 +857,8 @@ gen_select_tests() {
 %!assert (as(ridx,:), sparse (af(ridx,:)))
 %!assert (as(:,cidx), sparse (af(:,cidx)))
 %!assert (as(:,:), sparse (af(:,:)))
-%!assert (as((size (as,1):-1:1),:), sparse (af((size (af,1):-1:1),:)))
-%!assert (as(:,(size (as,2):-1:1)), sparse (af(:, (size (af,2):-1:1))))
+%!assert (as((rows (as):-1:1),:), sparse (af((size (af,1):-1:1),:)))
+%!assert (as(:,(columns (as):-1:1)), sparse (af(:, (size (af,2):-1:1))))
 
 %% Indexing tests
 %!assert (full (as([1,1],:)), af([1,1],:))
@@ -869,20 +869,20 @@ gen_select_tests() {
 
 %% Assignment test
 %!test
-%! ts = as; ts(:,:) = ts(fliplr (1:size (as,1)),:);
-%! tf = af; tf(:,:) = tf(fliplr (1:size (af,1)),:);
+%! ts = as; ts(:,:) = ts(fliplr (1:rows (as)),:);
+%! tf = af; tf(:,:) = tf(fliplr (1:rows (af)),:);
 %! assert (ts, sparse (tf));
 %!test
-%! ts = as; ts(fliplr (1:size (as,1)),:) = ts;
-%! tf = af; tf(fliplr (1:size (af,1)),:) = tf;
+%! ts = as; ts(fliplr (1:rows (as)),:) = ts;
+%! tf = af; tf(fliplr (1:rows (af)),:) = tf;
 %! assert (ts, sparse (tf));
 %!test
-%! ts = as; ts(:,fliplr (1:size (as,2))) = ts;
-%! tf = af; tf(:,fliplr (1:size (af,2))) = tf;
+%! ts = as; ts(:,fliplr (1:columns (as))) = ts;
+%! tf = af; tf(:,fliplr (1:columns (af))) = tf;
 %! assert (ts, sparse (tf));
 %!test
-%! ts(fliplr (1:size (as,1))) = as(:,1);
-%! tf(fliplr (1:size (af,1))) = af(:,1);
+%! ts(fliplr (1:rows (as))) = as(:,1);
+%! tf(fliplr (1:rows (af))) = af(:,1);
 %! assert (ts, sparse (tf));
 
 %% Deletion tests
@@ -1032,7 +1032,7 @@ cat <<EOF
 %! x = a \ b;
 %! assert (sparse (a * x), b, feps);
 %!endfunction
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! a = alpha*sprandn (10,11,0.2) + speye (10,11);
 %! f (a,[10,2],1e-10);
 %! ## Test this by forcing matrix_type, as can't get a certain
@@ -1069,32 +1069,32 @@ cat <<EOF
 %!assert (pds\xs, sparse (pdf\xs), 100*eps)
 %!test
 %! us = alpha*[[speye(10,10);sparse(1,10)],[[1,1];sparse(9,2);[1,1]]];
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! assert (us*(us\xf), xf, 100*eps);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! assert (us*(us\xs), xs, 100*eps);
 %!test
 %! pus = us(:,[2,1,3:12]);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! assert (pus*(pus\xf), xf, 100*eps);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! assert (pus*(pus\xs), xs, 100*eps);
 %!test
 %! us = alpha*[speye(11,9),[1;sparse(8,1);1;0]];
 %!testif HAVE_CXSPARSE
 %! [c,r] = qr (us, xf);
 %! assert (us\xf, r\c, 100*eps);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! [c,r] = qr (us, xs);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
 %! assert (us\xs, r\c, 100*eps);
 %!test
 %! pus = us(:,[1:8,10,9]);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! [c,r] = qr (pus, xf);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
 %! assert (pus\xf, r\c, 100*eps);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! [c,r] = qr (pus, xs);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
 %! assert (pus\xs, r\c, 100*eps);
@@ -1112,20 +1112,20 @@ cat <<EOF
 %! ls = alpha*[speye(10,10), sparse(10,1);[1;1], sparse(2,9),[1;1]];
 %! xf = beta * ones (12,2);
 %! xs = speye (12,12);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! [c,r] = qr (ls, xf);
 %! assert (ls\xf, r\c, 100*eps);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! [c,r] = qr (ls, xs);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
 %! assert (ls\xs, r\c, 100*eps);
-%!testif HAVE_CXSPARSE
+%!test
 %! pls = ls(:,[1:8,10,9]);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! [c,r] = qr (pls, xf);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
 %! assert (pls\xf, r\c, 100*eps);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! [c,r] = qr (pls, xs);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
 %! assert (pls\xs, r\c, 100*eps);
